==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/wreck/dialogs_nl.lua <==

dialogId("pot-v-lod", "font_big", "Could this be Captain Silver`s ship?")
dialogStr("Zou dit het schip van Kapitein Silver zijn?")


dialogId("pot-m-soud", "font_small", "What makes you think so?")
dialogStr("Hoe kom je daar bij?")


dialogId("pot-v-jmeno", "font_big", "The title of this level.")
dialogStr("De titel van dit veld.")


dialogId("pot-v-slus", "font_big", "It suits you.")
dialogStr("Dat staat je goed.")


dialogId("pot-m-dik", "font_small", "Thanks, you too.")
dialogStr("Dank je, jou ook.")


dialogId("pot-v-cepic", "font_big", "A very nice hat.")
dialogStr("Een mooie hoed.")


dialogId("pot-m-klob", "font_small", "Your stetson is quite good, too.")
dialogStr("Jou piratenhoed is ook niet slecht.")


dialogId("pot-v-hlave", "font_big", "What is that on your head?")
dialogStr("Wat heb jij nou op je kop?")


dialogId("pot-m-zima", "font_small", "My ears were freezing.")
dialogStr("Mijn oren waren koud.")


dialogId("pot-m-pujc", "font_small", "That`s some hat! Can I borrow it?")
dialogStr("Dat is pas een hoed! Mag ik hem lenen?")


dialogId("pot-v-leda", "font_big", "If you lend me yours.")
dialogStr("Als ik de jouwe mag lenen.")


dialogId("pot-m-velik", "font_small", "This sure is a big stetson.")
dialogStr("Dat is een grote piratenhoed.")


dialogId("pot-v-kras", "font_big", "And a beatiful one, too.")
dialogStr("En een hele mooie.")


dialogId("pot-v-nehnu", "font_big", "I can`t move this.")
dialogStr("Ik kan dit niet verschuiven.")


dialogId("pot-v-trub", "font_big", "I can`t move that cylinder.")
dialogStr("Ik krijg geen beweging in deze cylinder.")


dialogId("pot-m-nezb", "font_small", "I think we`re going to have to go inside that ship.")
dialogStr("Ik denk dat we het schip in zullen moeten.")


dialogId("pot-m-dovn", "font_small", "It looks like we have to go inside.")
dialogStr("Het lijkt erop dat we naarbinnen moeten.")


dialogId("pot-m-zatuch", "font_small", "The air in here smells so stale.")
dialogStr("Het ruikt hier binnen zo muf.")


dialogId("pot-v-nikdo", "font_big", "It seems that nobody`s here.")
dialogStr("Kennelijk is er niemand.")


dialogId("pot-m-moc", "font_small", "I don`t like it here.")
dialogStr("Ik vind het hier maar niks.")


dialogId("pot-v-plav", "font_big", "Stop talking and swim. Old ship interiors are highly interesting places.")
dialogStr("Hou op met kletsen en zwem eens wat door. Oude schepen zijn van binnen vaak erg interessant.")


dialogId("pot-v-ponur", "font_big", "Can you sense that atmosphere of doom and decay?")
dialogStr("Voel je de atmosfeer van dood en verdoemenis?")


dialogId("pot-m-hnil", "font_small", "No, just the mold.")
dialogStr("Nee, ik voel alleen maar schimmel.")


dialogId("pot-m-vidis", "font_small", "What do you see?")
dialogStr("Wat zie je?")


dialogId("pot-v-vidim", "font_big", "I can see many interesting levels which we`ll have to solve.")
dialogStr("Ik zie heel veel interessante velden die we zullen moeten oplossen.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/wreck/dialogs_nl.lua <==

dialogId("pot-v-lod", "font_big", "Could this be Captain Silver’s ship?")
dialogStr("Zou dit het schip van Kapitein Silver zijn?")


dialogId("pot-m-soud", "font_small", "What makes you think so?")
dialogStr("Hoe kom je daar bij?")


dialogId("pot-v-jmeno", "font_big", "The title of this level.")
dialogStr("De titel van dit veld.")


dialogId("pot-v-slus", "font_big", "It suits you.")
dialogStr("Dat staat je goed.")


dialogId("pot-m-dik", "font_small", "Thanks, you too.")
dialogStr("Dank je, jou ook.")


dialogId("pot-v-cepic", "font_big", "A very nice hat.")
dialogStr("Een mooie hoed.")


dialogId("pot-m-klob", "font_small", "Your stetson is quite good, too.")
dialogStr("Jou piratensteek is ook niet slecht.")


dialogId("pot-v-hlave", "font_big", "What is that on your head?")
dialogStr("Wat heb jij nou op je kop?")


dialogId("pot-m-zima", "font_small", "My ears were freezing.")
dialogStr("Ik had koude oren.")


dialogId("pot-m-pujc", "font_small", "That’s some hat! Can I borrow it?")
dialogStr("Dat is pas een hoed! Mag ik hem lenen?")


dialogId("pot-v-leda", "font_big", "If you lend me yours.")
dialogStr("Als ik de jouwe mag lenen.")


dialogId("pot-m-velik", "font_small", "This sure is a big stetson.")
dialogStr("Dat is een grote piratensteek, zeg.")


dialogId("pot-v-kras", "font_big", "And a beatiful one, too.")
dialogStr("En een hele mooie.")


dialogId("pot-v-nehnu", "font_big", "I can’t move this.")
dialogStr("Ik kan dit niet verschuiven.")


dialogId("pot-v-trub", "font_big", "I can’t move that cylinder.")
dialogStr("Ik krijg geen beweging in deze cylinder.")


dialogId("pot-m-nezb", "font_small", "I think we’re going to have to go inside that ship.")
dialogStr("Ik denk dat we het schip in zullen moeten.")


dialogId("pot-m-dovn", "font_small", "It looks like we have to go inside.")
dialogStr("Het lijkt erop dat we naarbinnen moeten.")


dialogId("pot-m-zatuch", "font_small", "The air in here smells so stale.")
dialogStr("Het ruikt hier binnen zo muf.")


dialogId("pot-v-nikdo", "font_big", "It seems that nobody’s here.")
dialogStr("Kennelijk is er niemand.")


dialogId("pot-m-moc", "font_small", "I don’t like it here.")
dialogStr("Ik vind het hier maar niks.")


dialogId("pot-v-plav", "font_big", "Stop talking and swim. Old ship interiors are highly interesting places.")
dialogStr("Hou op met kletsen en zwem eens wat door. Oude schepen zijn van binnen vaak erg interessant.")


dialogId("pot-v-ponur", "font_big", "Can you sense that atmosphere of doom and decay?")
dialogStr("Voel je de atmosfeer van dood en verderf?")


dialogId("pot-m-hnil", "font_small", "No, just the mold.")
dialogStr("Nee, ik voel alleen maar schimmel.")


dialogId("pot-m-vidis", "font_small", "What do you see?")
dialogStr("Wat zie je?")


dialogId("pot-v-vidim", "font_big", "I can see many interesting levels which we’ll have to solve.")
dialogStr("Ik zie heel veel interessante velden die we zullen moeten oplossen.")
